package com.ynet.life.util;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;
import java.util.Random;

/* loaded from: com_ynet_life_util.jar:com/ynet/life/util/RandomGUID.class */
public class RandomGUID {
    public String valueBeforeMD5 = "";
    public String valueAfterMD5 = "";
    private static Random myRand;
    private static SecureRandom mySecureRand;
    private static String s_id;

    static {
        SecureRandom secureRandom = new SecureRandom();
        mySecureRand = secureRandom;
        long secureInitializer = secureRandom.nextLong();
        myRand = new Random(secureInitializer);
        try {
            s_id = InetAddress.getLocalHost().toString();
        } catch (UnknownHostException e) {
            Trace.logError("LifeCore", e.getMessage(), e);
        }
    }

    public RandomGUID() {
        getRandomGUID(false);
    }

    public RandomGUID(boolean secure) {
        getRandomGUID(secure);
    }

    private void getRandomGUID(boolean secure) {
        long rand;
        MessageDigest md5 = null;
        StringBuffer sbValueBeforeMD5 = new StringBuffer();
        try {
            MessageDigest messageDigest = MessageDigest.getInstance("MD5");
            md5 = messageDigest;
            if (messageDigest == null) {
                Trace.logError("LifeCore", "MD5计算失败", new TranFailException("EBLN0035", "MD5计算失败"));
                return;
            }
        } catch (NoSuchAlgorithmException e) {
            Trace.logError("LifeCore", e.getMessage(), e);
        }
        try {
            long time = System.currentTimeMillis();
            if (secure) {
                rand = mySecureRand.nextLong();
            } else {
                rand = myRand.nextLong();
            }
            sbValueBeforeMD5.append(s_id);
            sbValueBeforeMD5.append(":");
            sbValueBeforeMD5.append(Long.toString(time));
            sbValueBeforeMD5.append(":");
            sbValueBeforeMD5.append(Long.toString(rand));
            this.valueBeforeMD5 = sbValueBeforeMD5.toString();
            md5.update(this.valueBeforeMD5.getBytes());
            byte[] array = md5.digest();
            StringBuffer sb = new StringBuffer();
            for (byte b : array) {
                int b2 = b & 255;
                if (b2 < 16) {
                    sb.append('0');
                }
                sb.append(Integer.toHexString(b2));
            }
            this.valueAfterMD5 = sb.toString();
        } catch (Exception e2) {
            Trace.logError("LifeCore", e2.getMessage(), e2);
        }
    }

    public static String generateDigest(String sourceStr) {
        MessageDigest md5 = null;
        try {
            md5 = MessageDigest.getInstance("MD5");
        } catch (NoSuchAlgorithmException e) {
            Trace.logError("LifeCore", e.getMessage(), e);
        }
        md5.update(sourceStr.getBytes());
        byte[] array = md5.digest();
        StringBuffer sb = new StringBuffer();
        for (byte b : array) {
            int b2 = b & 255;
            if (b2 < 16) {
                sb.append('0');
            }
            sb.append(Integer.toHexString(b2));
        }
        return sb.toString();
    }

    public static String getRandom(int length) {
        if (length > 32) {
            length = 32;
        }
        return new RandomGUID().valueAfterMD5.toUpperCase().substring(0, length);
    }

    public static final String toFixedIntStr(String str) {
        int h = 0;
        int off = 0;
        if (str == null) {
            return "91234";
        }
        char[] val = str.toCharArray();
        int len = val.length;
        for (int i = 0; i < len; i++) {
            int i2 = off;
            off++;
            h = (h * 31) + val[i2];
        }
        return String.valueOf(Math.abs(h)) + "91234";
    }

    public String toString() {
        String raw = this.valueAfterMD5.toUpperCase();
        System.out.println("Raw:" + raw.length());
        StringBuffer sb = new StringBuffer();
        sb.append(raw.substring(0, 12));
        sb.append("-");
        sb.append(raw.substring(8, 12));
        sb.append("-");
        sb.append(raw.substring(12, 16));
        sb.append("-");
        sb.append(raw.substring(16, 20));
        sb.append("-");
        sb.append(raw.substring(20));
        return sb.toString();
    }

    public static void main(String[] args) {
        System.out.println(toFixedIntStr("10531112198201011234"));
    }
}
